"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.run = void 0;
const client_ssm_1 = require("@aws-sdk/client-ssm");
// @ts-ignore
const rds_query_processor_1 = require("rds-query-processor");
let adapter;
let secretsClient;
const delay = (ms) => new Promise((resolve) => setTimeout(resolve, ms));
const WAIT_COMPLETE = 'WAIT_COMPLETE';
const run = (event) => __awaiter(void 0, void 0, void 0, function* () {
    if (!adapter) {
        const config = yield getDBConfig();
        adapter = yield (0, rds_query_processor_1.getDBAdapter)(config);
    }
    const debugMode = process.env.DEBUG_MODE === 'true';
    const result = yield adapter.executeRequest(event, debugMode);
    return result;
});
exports.run = run;
const createSSMClient = () => {
    var _a;
    const DNS_SEPERATOR = ':';
    const endpoint = (_a = process.env.SSM_ENDPOINT) === null || _a === void 0 ? void 0 : _a.split(DNS_SEPERATOR).pop();
    secretsClient = new client_ssm_1.SSMClient({
        endpoint: `https://${endpoint}`,
    });
};
const wait10Seconds = () => __awaiter(void 0, void 0, void 0, function* () {
    yield delay(10000);
    return WAIT_COMPLETE;
});
const getSSMValue = (key) => __awaiter(void 0, void 0, void 0, function* () {
    var _a, _b, _c;
    if (!key) {
        throw Error('Key not provided to retrieve database connection secret');
    }
    const parameterCommand = new client_ssm_1.GetParameterCommand({
        Name: key,
        WithDecryption: true,
    });
    // When the lambda is deployed in VPC and VPC endpoints for SSM are not defined or
    // the security group's inbound rule for port 443 is not defined,
    // the SSM client waits for the entire lambda execution time and times out.
    // If the parameter is not retrieved within 10 seconds, throw an error.
    const data = yield Promise.race([secretsClient.send(parameterCommand), wait10Seconds()]);
    // If string is returned, throw error.
    if ((typeof data === 'string' || data instanceof String) &&
        data === WAIT_COMPLETE) {
        console.log('Unable to retrieve secret for database connection from SSM. If your database is in VPC, verify that you have VPC endpoints for SSM defined and the security group\'s inbound rule for port 443 is defined.');
        throw new Error('Unable to get the database credentials. Check the logs for more details.');
    }
    // Read the value from the GetParameter response.
    const response = data;
    if ((((_a = response === null || response === void 0 ? void 0 : response.$metadata) === null || _a === void 0 ? void 0 : _a.httpStatusCode) && ((_b = response === null || response === void 0 ? void 0 : response.$metadata) === null || _b === void 0 ? void 0 : _b.httpStatusCode) >= 400) || !((_c = response === null || response === void 0 ? void 0 : response.Parameter) === null || _c === void 0 ? void 0 : _c.Value)) {
        throw new Error('Unable to get secret for database connection');
    }
    return response.Parameter.Value;
});
const getDBConfig = () => __awaiter(void 0, void 0, void 0, function* () {
    if (!secretsClient) {
        createSSMClient();
    }
    const config = {
        engine: getDBEngine(),
        host: yield getSSMValue(process.env.host),
        port: Number.parseInt(yield getSSMValue(process.env.port)) || 3306,
        username: yield getSSMValue(process.env.username),
        password: yield getSSMValue(process.env.password),
        database: yield getSSMValue(process.env.database),
    };
    if (!config.host || !config.port || !config.username || !config.password || !config.database) {
        throw Error('Missing database connection configuration');
    }
    return config;
});
const getDBEngine = () => {
    if (!process.env.engine) {
        throw Error('Missing database engine configuration');
    }
    return process.env.engine;
};
//# sourceMappingURL=handler.js.map